# Project


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**name** | **str** | Name of the project | 
**cloud** | **bool, date, datetime, dict, float, int, list, str, none_type** |  | [readonly] 
**created_at** | **datetime** | Creation date | [readonly] 
**updated_at** | **datetime** | Date of the last update | [readonly] 
**root_folder_id** | **int, none_type** |  | [readonly] 
**logo** | **str, none_type** |  | [optional] 
**status** | **str** |  | [optional] 
**parent_id** | **int, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


